/*Demonstration Data Set Creation for Spline Macros*/
libname fram 'C:\Users\gagnon\Dropbox\Theory\Splines\Final 2-20';
options mprint symbolgen mlogic ;

data analytic; set fram.fram;
if period eq 1;
keep age bmi death sex randid timedth linkf yrsdthcat yrsdth agegrp agegrp3 time0;
yrsdth = timedth/365.25;
yrsdthcat = ceil(yrsdth);
linkf = log(yrsdth);
label bmi = 'Body Mass Index';
agegrp = age lt 55;
if age lt 45 then agegrp3 = 1;
else if 45 le age le 55 then agegrp3 = 2;
else if age gt 55 then agegrp3 = 3;
if bmi lt 20 then bmigrp = 1;
else if 20 le bmi lt 25 then bmigrp = 2;
else if 25 le bmi lt 30 then bmigrp = 3;
else if 30 le bmi lt 35 then bmigrp = 4;
else if bmi ge 35 then bmigrp = 5;
time0=0;
run;
/************************************************************************
*  Please execute the COMBINED SPLINE MACROS program before continuing  * 
*  beyond this point.                                                   *
************************************************************************/

/*  
STEP ONE:  Set up the graphics environment. Modify and execute one of the following:

Sample executions of %graphset:
%graphset(C:\Users\David\Documents\figure output\test1.pdf,,splinecurve,format=pdf,type=pdf);
%graphset(C:\Users\David\Documents\figure output,,splinecurve,format=emf,type=listing);
%graphset(C:\Users\David\Documents\figure output,,splinecurve,format=jpeg,type=listing);
*/
%graphset(C:\Users\gagnon\Documents\figure output,,splinecurve,format=jpeg,type=listing);

/*NEXT STEP: Execute one of the following macros*/


/*Spline macro for non-survival outcomes without effect modification/subgroups */
%glimsp(data=analytic,var=bmi,refval=25,covar= age sex,class=sex,outcome=death,
          nknots=10,method=3,dist=poisson,link=log,offset=linkf,weight=NONE,
          min_x=15,max_x=40,by_x=5,min_y=0,max_y=3,by_y=1);
run;

/*Spline macro for non-survival outcomes with effect modification/subgroups */
/*With risk/odds type outcome data:*/
%glimspem(data=analytic,var=BMI,refval=25,emvar=agegrp3,emref=1,
          covar=sex,class=sex,outcome=death,nknots=5,method=3,dist=poisson,
          link=log,offset=linkf,weight=NONE,min_x=15,max_x=40,by_x=5,min_y=0,max_y=10,
          by_y=1,CI=YES,color=YES,bins=20);
run;
/*With normally distributed outcome data:*/
%glimspem(data=analytic,var=age,refval=50,emvar=bmigrp,emref=2,
          covar=sex,class=sex,outcome=sysbp,nknots=5,method=3,dist=NORMAL,
          link=IDENTITY,offset=,weight=NONE,min_x=30,max_x=70,by_x=10,min_y=80,max_y=300,
          by_y=20,CI=YES,color=YES,bins=20);
run;
/*Spline macro for survival outcomes without effect modification/subgroups*/
%phregsp(data=analytic,var=bmi,refval=25,covar=age sex,class=sex,outcome=death,time0=,
           time1=timedth,reftime=365,nknots=8,method=3,weight=NONE,min_x=15,max_x=43,by_x=5,
           min_y=0,max_y=3,by_y=1);
run;

/*Spline macro for survival outcomes with effect modification/subgroups*/
%phregspem(data=analytic,var=BMI,refval=25,emvar=agegrp3,emref=1,covar=sex,
             class=sex,outcome=death,time0=time0,time1=timedth,reftime=3653,nknots=5,method=3,
             weight=NONE,min_x=15,max_x=40,by_x=5,min_y=0,max_y=20,by_y=2,CI=YES,color=NO);
run;
